#
# spec file for package upmpdcli
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           upmpdcli
Version:        1.6.2
Release:        bp155.1.6
Summary:        UPnP Media Renderer front-end to MPD, the Music Player Daemon
License:        GPL-2.0-or-later
URL:            https://www.lesbonscomptes.com/updmpdcli
Source0:        https://www.lesbonscomptes.com/upmpdcli/downloads/upmpdcli-%{version}.tar.gz
Source1:        https://www.lesbonscomptes.com/upmpdcli/downloads/upmpdcli-%{version}.tar.gz.asc
Source2:        https://www.lesbonscomptes.com/pages/jf-at-dockes.org.pub#/%{name}.keyring
Patch0:         harden_upmpdcli.service.patch
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  group(audio)
BuildRequires:  pkgconfig(jsoncpp)
BuildRequires:  pkgconfig(libmicrohttpd)
BuildRequires:  pkgconfig(libmpdclient)
BuildRequires:  pkgconfig(libnpupnp)
BuildRequires:  pkgconfig(libupnpp)
Requires(pre):  group(audio)
Requires(pre):  shadow
%{?systemd_ordering}

%description
Upmpdcli turns MPD, the Music Player Daemon into an UPnP Media Renderer,
usable with most UPnP Control Point applications, such as those which run
on Android tablets or phones.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
install -D -m 644 systemd/upmpdcli.service %{buildroot}%{_unitdir}/upmpdcli.service
mkdir -p %{buildroot}/%{_sbindir}
ln -s service %{buildroot}/%{_sbindir}/rcupmpdcli

%files
%license COPYING
%doc AUTHORS
%{_bindir}/%{name}
%{_bindir}/scctl
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_unitdir}/upmpdcli.service
%{_sbindir}/rcupmpdcli
%config(noreplace) %{_sysconfdir}/upmpdcli.conf

%pre
getent passwd upmpdcli >/dev/null || useradd -r -g audio -d /nonexistent -s /sbin/nologin -c "user for upmpdcli" upmpdcli
%service_add_pre upmpdcli.service

%post
%service_add_post upmpdcli.service

%preun
%service_del_preun upmpdcli.service

%postun
%service_del_postun upmpdcli.service

%changelog
* Sat Dec  3 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.6.2:
  * Media Server: uprcl, qobuz, upradios: properly implement
    UPnP Browse(Metadata), for the sole use of Kodi, probably.
  * Uprcl container sort: sort by file names if there are no tags
    (e.g. wav files).
  * Uprcl: add uprclnotag view configuration variable to disable the
    "Tag View" entries in the folders tree.
  * Make configuration parameter names case-insensitive
  * Small bugs fixes
- update to 1.6.1:
  * uprcl: process custom tags (not predefined anywhere) as regular ones.
  * main: change order of media server and renderer initialisations so
    that the media server does not have to wait for mpd.
- update to 1.6.0:
  * Allow all configuration variables to also be set through
    environment variables named UPMPD_xxx where xxx is the upper-cased
    version of the variable name. This should facilitate running
    upmpdcli in a container.
  * Change the names of the low level UPnP library log variables from
    UPMPDCLI_xxx to UPMPD_xxx and manage them in the same way as the rest
    (with config entries too).
  * Allow substituting the host name (%%h,%%H) and version info (%%v) in
    the configured friendlyname. The default friendlyname is now UpMpd-%%h
  * Uprcl: use same host as upmpdcli by default. Add uprclport configuration
    variable to only set the port
- update to 1.5.20:
  * Uprcl: preserve stored playlist order
  * Uprcl: choose folder image file rather than track-embedded art for folder or album
  * Uprcl: misc fixes.
* Sat Aug 13 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.19:
  * Fix uprcl web control interface (asking for update did not work)
  * Fix upradios stations list order
- update to 1.5.18:
  * Create an upmpdcli group during installation and change the group
    to upmpdcli when started as root (in addition to the setuid())
  * uprcl: try to show more information when the initialisation fails
* Wed Jun  1 2022 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.17:
  * Fix Qobuz plugin consecutively to small change in Qobuz interface
- update to 1.5.16:
  * Fix radios using Apple Live Streaming, which were broken in 1.5.14
- update to 1.5.15:
  * Fix possible deadlocks when switching to Songcast mode
- update to 1.5.14:
  * Added mediaserver module for listing and listening to  BBC radio stations
* Sun Mar 20 2022 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Tue Dec 14 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.13:
  * Enable L16 by default as it is handled correctly by current mpd versions
  * Add the mpd version to the description version string
  * Change Qobuz default format to 6 (44.1/16 FLAC)
  * Misc small bug fixes
- update to 1.5.12:
  * Add small Media Server plugin (upradios) for exporting the radio list
  * uprcl: export the radio list as a playlist
  * uprcl: small improvements
  * Deezer, Qobuz: set pictures for artists and playlists
* Fri Nov 26 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_upmpdcli.service.patch
* Thu Apr 15 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.11:
  * Fix rare possible issue with Kazoo volume control
  * Passthrough for CDDA urls. An URL of the form:
    http://upmpdprotoescape/cdda/dev/sr0/1
    will be translated to: cdda:///dev/sr0/1
    This hack allows tunneling CDDA URLs, which mpd understands but
    some control points don’t like, for example, to construct a
    playlist which will play the tracks from a CD device
  * Reconnect the event loop when mpd restarts. Before the fix,
    events stopped being generated after mpd restarted
  * Radio metadata issues fixed
  * Media Server: Deezer streaming service plugin
  * Fix events not working when mpd had password set
* Tue Jan 19 2021 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.8:
  * Fix a number of memory leak and locking issues detected by valgrind/helgrind.
  * Improve performance of big playlist insert by rate-limiting events.
  * Fix possible crash when started while mpd is not running.
* Thu Dec 31 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.7:
  * Fix timeout issue while in long pause
    (>60S, play transition started from other client was not detected)
  * Fix ohinfo issue resulting in no cover art display in Kazoo "currently playing" screen.
  * Fix a number of issues in radio metadata.
  * The minimum effective volume adjustment was 5. Reset it to 1.
  * Cache update issues in OH playlist resulted in incomplete metadata.
* Wed Dec  9 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.5:
  * Fix issue with removing tracks from the playlist (sometimes slow or freezed).
  * Fix bad locking causing multiple execs of radio scripts.
  * Setting lumincompat = 1 is not useful any more and crashes some Kazoo versions.
    So you should keep the default value which is off.
  * Improve metadata processing when playing radios with BubbleDS.
* Wed Nov 25 2020 Michael Pujos <pujos.michael@gmail.com>
- update to 1.5.2:
  * Modify a few things which should not have mattered but which prevented Lumin to work with upmpdcli
  * Qobuz plugin working again (for now), by identifying itself as the web client (thanks to qobuz-dl on github)
  * Fixed crash
  * Will now generate events for bitrate changes when playing
- update to 1.5.1:
  * Fix small issue resulting in missing metadata in ohinfo
* Thu Nov 19 2020 Michael Pujos <pujos.michael@gmail.com>
- removed unneeded systemd.obscpio
- spec: removed unneeded %%global __python python3
- spec: removed unneeded autoconf, automake build deps
* Sun Nov 15 2020 Michael Pujos <pujos.michael@gmail.com>
- update to upstream version 1.5.0
* Sat May 16 2020 Michael Pujos <pujos.michael@gmail.com>
- added explicit dependency on libupnp to force packqhe recompilaiton
  when libupnp version changes (eg libupnp15 => libupnp16)
* Fri Jan 24 2020 Michael Pujos <pujos.michael@gmail.com>
- Initial version of upmpdcli 1.4.5
